@@ -1,7 +1,7 @@
 # This Python file uses the following encoding: utf-8
 
 """
-$Id: googlevideo.py 107062 2009-12-19 02:43:52Z erico_andrei $
+$Id: googlevideo.py 112896 2010-03-12 23:19:06Z erico_andrei $
 """
 
 __author__ = 'Héctor Velarde <hvelarde@jornada.com.mx>'
@@ -134,7 +134,15 @@ class ATGoogleVideo(ATCTContent, HistoryAwareMixin, ATCTImageTransform):
             if image is not None and not isinstance(image, basestring):
                 # image might be None or '' for empty images
                 return image
-
+        
         return ATCTContent.__bobo_traverse__(self, REQUEST, name)
+    
+    def getRemoteUrl(self):
+        '''Returns docId from this object
+           This way we don't need to add a new metadata to
+           the catalog
+        '''
+        return self.getDocId()
+        
 
 registerType(ATGoogleVideo, PROJECTNAME)
